default_changelog_header = """
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
"""


default_change_file_template = """
## {version_header}

### Added

No changes.

### Changed

No changes.

### Removed

No changes.

### Fixed

No changes.

### Deprecated

No changes.
"""
